@@ -15,13 +15,14 @@ import os
 from toscaparser.common import exception
 from toscaparser import functions
 from toscaparser.tests.base import TestCase
+from toscaparser.tests import utils
 from toscaparser.tosca_template import ToscaTemplate
 from toscaparser.utils.gettextutils import _
 
 
 class IntrinsicFunctionsTest(TestCase):
 
-    tosca_tpl = TestCase.test_sample(
+    tosca_tpl = utils.get_sample_test_path(
         "data/tosca_single_instance_wordpress.yaml")
     params = {'db_name': 'my_wordpress', 'db_user': 'my_db_user',
               'db_root_pwd': '12345678'}
@@ -119,7 +120,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual(dbms_root_password.result(), '12345678')
 
     def test_get_property_with_host(self):
-        tosca_tpl = TestCase.test_sample(
+        tosca_tpl = utils.get_sample_test_path(
             "data/functions/test_get_property_with_host.yaml")
         mysql_database = self._get_node('mysql_database',
                                         ToscaTemplate(tosca_tpl,
@@ -137,7 +138,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual(1, result)
 
     def test_get_property_with_nested_params(self):
-        tosca_tpl = TestCase.test_sample(
+        tosca_tpl = utils.get_sample_test_path(
             "data/functions/tosca_nested_property_names_indexes.yaml")
         webserver = self._get_node('wordpress',
                                    ToscaTemplate(tosca_tpl,
@@ -152,7 +153,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual(3, wp_list_prop.result())
 
     def test_get_property_with_capabilties_inheritance(self):
-        tosca_tpl = TestCase.test_sample(
+        tosca_tpl = utils.get_sample_test_path(
             "data/functions/test_capabilties_inheritance.yaml")
         some_node = self._get_node('some_node',
                                    ToscaTemplate(tosca_tpl,
@@ -164,7 +165,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual('someval', some_input.result())
 
     def test_get_property_source_target_keywords(self):
-        tosca_tpl = TestCase.test_sample(
+        tosca_tpl = utils.get_sample_test_path(
             "data/functions/test_get_property_source_target_keywords.yaml")
         tosca = ToscaTemplate(tosca_tpl,
                               parsed_params={'db_root_pwd': '1234'})
@@ -184,7 +185,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual(3306, source_port.result())
 
     def test_get_prop_cap_host(self):
-        tosca_tpl = TestCase.test_sample(
+        tosca_tpl = utils.get_sample_test_path(
             "data/functions/test_get_prop_cap_host.yaml")
         some_node = self._get_node('some_node',
                                    ToscaTemplate(tosca_tpl))
@@ -193,7 +194,7 @@ class IntrinsicFunctionsTest(TestCase):
         self.assertEqual('someval', some_prop.value.result())
 
     def test_get_prop_cap_bool(self):
-        tosca_tpl = TestCase.test_sample(
+        tosca_tpl = utils.get_sample_test_path(
             "data/functions/test_get_prop_cap_bool.yaml")
         some_node = self._get_node('software',
                                    ToscaTemplate(tosca_tpl))
@@ -206,7 +207,7 @@ class GetAttributeTest(TestCase):
 
     def _load_template(self, filename):
         return ToscaTemplate(os.path.join(
-            TestCase.test_sample('data'), filename),
+            utils.get_sample_test_path('data'), filename),
             parsed_params={'db_root_pwd': '1234'})
 
     def _get_operation(self, interfaces, operation):
@@ -303,7 +304,7 @@ class GetAttributeTest(TestCase):
               'Unexpected attribute/index value "0"'))
 
     def test_get_attribute_source_target_keywords(self):
-        tosca_tpl = TestCase.test_sample(
+        tosca_tpl = utils.get_sample_test_path(
             "data/functions/test_get_attribute_source_target_keywords.yaml")
         tosca = ToscaTemplate(tosca_tpl,
                               parsed_params={'db_root_pwd': '12345678'})
@@ -344,7 +345,7 @@ class GetAttributeTest(TestCase):
 class ConcatTest(TestCase):
 
     def _load_template(self, filename):
-        return ToscaTemplate(TestCase.test_sample(filename))
+        return ToscaTemplate(utils.get_sample_test_path(filename))
 
     def test_validate_concat(self):
         tosca = self._load_template("data/functions/test_concat.yaml")
@@ -365,7 +366,7 @@ class ConcatTest(TestCase):
 class TokenTest(TestCase):
 
     def _load_template(self, filename):
-        return ToscaTemplate(TestCase.test_sample(filename))
+        return ToscaTemplate(utils.get_sample_test_path(filename))
 
     def test_validate_token(self):
         tosca = self._load_template("data/functions/test_token.yaml")
