@@ -11,13 +11,14 @@
 #    under the License.
 
 from toscaparser.tests.base import TestCase
+from toscaparser.tests import utils
 from toscaparser.tosca_template import ToscaTemplate
 
 
 class ToscaNFVTemplateTest(TestCase):
 
     '''TOSCA NFV template.'''
-    tosca_tpl = TestCase.test_sample(
+    tosca_tpl = utils.get_sample_test_path(
         "data/extensions/tosca_helloworld_nfv.yaml")
     tosca = ToscaTemplate(tosca_tpl)
 
